summaryrefslogtreecommitdiffstatshomepage
path: root/src/devices/sound/t6w28.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/devices/sound/t6w28.cpp')
-rw-r--r--src/devices/sound/t6w28.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/devices/sound/t6w28.cpp b/src/devices/sound/t6w28.cpp
index cc7324d41f1..6c024c37757 100644
--- a/src/devices/sound/t6w28.cpp
+++ b/src/devices/sound/t6w28.cpp
@@ -101,10 +101,10 @@ void t6w28_device::write(offs_t offset, uint8_t data)
//-------------------------------------------------
// sound_stream_update - handle a stream update
//-------------------------------------------------
-void t6w28_device::sound_stream_update(sound_stream &stream, stream_sample_t **inputs, stream_sample_t **outputs, int samples)
+void t6w28_device::sound_stream_update_legacy(sound_stream &stream, stream_sample_t const * const *inputs, stream_sample_t * const *outputs, int samples)
{
int i;
stream_sample_t *buffer0 = outputs[0];
@@ -296,7 +296,7 @@ void t6w28_device::device_start()
int i;
m_sample_rate = clock() / 16;
- m_channel = machine().sound().stream_alloc(*this, 0, 2, m_sample_rate);
+ m_channel = stream_alloc_legacy(0, 2, m_sample_rate);
for (i = 0;i < 8;i++) m_volume[i] = 0;
@@ -101,10 +101,10 @@ void t6w28_device::write(offs_t offset, uint8_t data)
//-------------------------------------------------
-// sound_stream_update - handle a stream update
+// sound_stream_update_legacy - handle a stream update
//-------------------------------------------------